@@ -53,72 +53,6 @@ typedef struct {
 
 static GList *hash_tables_to_free_at_exit;
 
-/* We will need this for eel_unsetenv if there is no unsetenv. */
-#if !defined (HAVE_UNSETENV)
-extern char **environ;
-#endif
-
-/**
- * eel_setenv:
- * 
- * Adds "*name=*value" to the environment
- *
- * Returns: see "putenv" - 
- * 
- **/
-int
-eel_setenv (const char *name, const char *value, gboolean overwrite)
-{
-#if defined (HAVE_SETENV)
-	return setenv (name, value, overwrite);
-#else
-	char *string;
-	
-	if (! overwrite && g_getenv (name) != NULL) {
-		return 0;
-	}
-	
-	/* This results in a leak when you overwrite existing
-	 * settings. It would be fairly easy to fix this by keeping
-	 * our own parallel array or hash table.
-	 */
-	string = g_strconcat (name, "=", value, NULL);
-	return putenv (string);
-#endif
-}
-
-/**
- * eel_unsetenv:
- * 
- * Removes *name from the environment
- * 
- **/
-void
-eel_unsetenv (const char *name)
-{
-#if defined (HAVE_UNSETENV)
-	unsetenv (name);
-#else
-	int i, len;
-
-	len = strlen (name);
-	
-	/* Mess directly with the environ array.
-	 * This seems to be the only portable way to do this.
-	 */
-	for (i = 0; environ[i] != NULL; i++) {
-		if (strncmp (environ[i], name, len) == 0
-		    && environ[i][len] == '=') {
-			break;
-		}
-	}
-	while (environ[i] != NULL) {
-		environ[i] = environ[i + 1];
-		i++;
-	}
-#endif
-}
-
 /**
  * eel_g_date_new_tm:
  * 
